# chpip

[![Run Tests](https://github.com/Prodesire/chpip/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/Prodesire/chpip/actions/workflows/tests.yml)

A tool to manage the base URL of the Python package index.
